# Phenopype: a phenotyping pipeline for Python
<img src="https://raw.githubusercontent.com/mluerig/phenopype/master/assets/coverage.svg">
<img src="https://raw.githubusercontent.com/mluerig/phenopype/master/assets/logo.png">

<div align="justify">

<strong>Phenopype is a high throughput phenotyping pipeline for Python that aims at supporting biologists in their efforts to extract high dimensional phenotypic data from digital images</strong>. Phenopype provides high level image-preprocessing, -segmentation, and -analysis functions that can be executed sequentially in a semi or fully automated fashion. Users can assemble their own function-stacks that can be customized and stored along with raw data for full reproducibility. Phenopype can be run from Python or from a Python Integrated Development Environment (IDE), like <i>Spyder</i>. Phenopype is designed to provide robust image analysis workflows that can be implemented with little or no Python experience.<br>

</div>

## Getting started
<ol>
<li><a href="https://mluerig.github.io/phenopype/installation.html">Install Phenopype </a> - via the <i>Python Package Index</i> (PYPI): <code>pip install phenopype</code></li> 
<li><a href="https://mluerig.github.io/phenopype/tutorial_0.html">Run the Tutorials </a> - Tutorial 1 is for Python beginners, otherwise Tutorial 2 is a good starting point </li>
<li><a href="https://mluerig.github.io/phenopype/index.html#examples">Check the Examples</a> - Example 1 delineates a typical computer vision workflow </li>
</ol>

## Documentation
Full documentation can be found here: https://mluerig.github.io/phenopype/
